@@ -72,18 +72,19 @@ class AIOWifiLedBulb(LEDENETDevice):
 
     async def async_turn_on(self) -> None:
         """Turn on the device."""
-        await self._async_turn_on_with_retry()
-        self._set_power_state_ignore_next_push(self._protocol.on_byte)
+        if await self._async_turn_on_with_retry():
+            self._set_power_state_ignore_next_push(self._protocol.on_byte)
 
-    async def _async_turn_on_with_retry(self) -> None:
+    async def _async_turn_on_with_retry(self) -> bool:
         calls = (self._async_turn_on, self._async_turn_off_on, self._async_turn_on)
         for idx, call in enumerate(calls):
             if (
                 await self._async_execute_and_wait_for(self._on_futures, call)
                 or self.is_on
             ):
-                return
+                return True
             _LOGGER.debug("Failed to turn on (%s/%s)", 1 + idx, len(calls))
+        return False
 
     async def _async_turn_off(self) -> None:
         await self._async_send_msg(self._protocol.construct_state_change(False))
@@ -94,18 +95,19 @@ class AIOWifiLedBulb(LEDENETDevice):
 
     async def async_turn_off(self) -> None:
         """Turn off the device."""
-        await self._async_turn_off_with_retry()
-        self._set_power_state_ignore_next_push(self._protocol.off_byte)
+        if await self._async_turn_off_with_retry():
+            self._set_power_state_ignore_next_push(self._protocol.off_byte)
 
-    async def _async_turn_off_with_retry(self) -> None:
+    async def _async_turn_off_with_retry(self) -> bool:
         calls = (self._async_turn_off, self._async_turn_on_off, self._async_turn_off)
         for idx, call in enumerate(calls):
             if (
                 await self._async_execute_and_wait_for(self._off_futures, call)
                 or not self.is_on
             ):
-                return
+                return True
             _LOGGER.debug("Failed to turn off (%s/%s)", 1 + idx, len(calls))
+        return False
 
     async def async_set_white_temp(self, temperature, brightness, persist=True) -> None:
         """Set the white tempature."""
@@ -190,29 +192,23 @@ class AIOWifiLedBulb(LEDENETDevice):
         start_empty_buffer = not self._buffer
         self._buffer += data
         self._updates_without_response = 0
-        # Some of the older bulbs respond to a state request in
-        # multiple packets so we have to reassemble.  Currently
-        # we only know how to reassemble state responses
-        if (
-            # if the buffer has the start of a state response
-            self._protocol.is_start_of_state_response(self._buffer)
-            # If the buffer does not have a full state response
-            and not self._protocol.is_valid_state_response(self._buffer)
-            # .. and the buffer is not longer than the a valid state response
-            and not self._protocol.is_longer_than_state_response(self._buffer)
-        ):
-            # We wait for more data. Otherwise we process the message
-            return
-        msg = self._buffer
-        self._buffer = b""
-        if not start_empty_buffer:
-            _LOGGER.debug(
-                "%s <= Reassembled (%s) (%d)",
-                self._aio_protocol.peername,
-                " ".join(f"0x{x:02X}" for x in msg),
-                len(msg),
-            )
-        self._async_process_message(msg)
+        msg_length = len(self._buffer)
+        while msg_length:
+            expected_length = self._protocol.expected_response_length(self._buffer)
+            if msg_length < expected_length:
+                # need more bytes
+                return
+            msg = self._buffer[:expected_length]
+            self._buffer = self._buffer[expected_length:]
+            msg_length = len(self._buffer)
+            if not start_empty_buffer:
+                _LOGGER.debug(
+                    "%s <= Reassembled (%s) (%d)",
+                    self._aio_protocol.peername,
+                    " ".join(f"0x{x:02X}" for x in msg),
+                    len(msg),
+                )
+            self._async_process_message(msg)
 
     def _async_process_message(self, msg):
         """Process a full message (maybe reassembled)."""
@@ -223,6 +219,8 @@ class AIOWifiLedBulb(LEDENETDevice):
             return
         assert self._updated_callback is not None
         prev_state = self.raw_state
+        if self.addressable and self._protocol.is_valid_addressable_response(msg):
+            self.process_addressable_response(msg)
         if self._protocol.is_valid_state_response(msg):
             self.process_state_response(msg)
         elif self._protocol.is_valid_power_state_response(msg):
@@ -237,6 +235,15 @@ class AIOWifiLedBulb(LEDENETDevice):
             futures.clear()
             self._updated_callback()
 
+    def process_addressable_response(self, msg):
+        _LOGGER.debug(
+            "%s <= Extracted response (%s) (%d)",
+            self._aio_protocol.peername,
+            " ".join(f"0x{x:02X}" for x in msg[10:-1]),
+            len(msg[10:-1]),
+        )
+        return self.process_state_response(msg[10:-1])
+
     async def _async_send_msg(self, msg):
         """Write a message on the socket."""
         if not self._aio_protocol:
