@@ -6,7 +6,6 @@ import time
 from .const import (  # imported for back compat, remove once Home Assistant no longer uses
     ADDRESSABLE_STATE_CHANGE_LATENCY,
     CHANNEL_STATES,
-    COLOR_MODE_ADDRESSABLE,
     COLOR_MODE_CCT,
     COLOR_MODE_DIM,
     COLOR_MODE_RGB,
@@ -25,6 +24,7 @@ from .const import (  # imported for back compat, remove once Home Assistant no
     MODE_SWITCH,
     MODE_WW,
     MODEL_NUMS_SWITCHS,
+    PRESET_MUSIC_MODE,
     STATE_BLUE,
     STATE_CHANGE_LATENCY,
     STATE_COOL_WHITE,
@@ -42,6 +42,7 @@ from .models_db import (
     CHANNEL_REMAP,
     MODEL_DESCRIPTIONS,
     MODEL_MAP,
+    ORIGINAL_ADDRESSABLE_MODELS,
     RGBW_PROTOCOL_MODELS,
     UNKNOWN_MODEL,
     USE_9BYTE_PROTOCOL_MODELS,
@@ -54,6 +55,8 @@ from .pattern import (
     EFFECT_CUSTOM_CODE,
     EFFECT_ID_NAME,
     EFFECT_LIST,
+    ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME,
+    ORIGINAL_ADDRESSABLE_EFFECT_NAME_ID,
     PresetPattern,
 )
 from .protocol import (
@@ -61,10 +64,12 @@ from .protocol import (
     PROTOCOL_LEDENET_9BYTE,
     PROTOCOL_LEDENET_ADDRESSABLE,
     PROTOCOL_LEDENET_ORIGINAL,
+    PROTOCOL_LEDENET_ORIGINAL_ADDRESSABLE,
     ProtocolLEDENET8Byte,
     ProtocolLEDENET9Byte,
     ProtocolLEDENETAddressable,
     ProtocolLEDENETOriginal,
+    ProtocolLEDENETOriginalAddressable,
 )
 from .timer import BuiltInTimer
 from .utils import utils, white_levels_to_color_temp
@@ -130,6 +135,15 @@ class LEDENETDevice:
         """Devices that have addressable leds."""
         return model_num in ADDRESSABLE_MODELS
 
+    @property
+    def original_addressable(self):
+        """Devices that have addressable leds using the original addressable protocol."""
+        return self._is_original_addressable(self.model_num)
+
+    def _is_original_addressable(self, model_num):
+        """Devices that have addressable leds using the original addressable protocol."""
+        return model_num in ORIGINAL_ADDRESSABLE_MODELS
+
     @property
     def rgbwcapable(self):
         """Devices that actually support rgbw."""
@@ -244,6 +258,8 @@ class LEDENETDevice:
     @property
     def effect_list(self):
         """Return the list of available effects."""
+        if self.original_addressable:
+            return ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME.values()
         if self.addressable:
             return ADDRESSABLE_EFFECT_ID_NAME.values()
         return EFFECT_LIST
@@ -252,15 +268,20 @@ class LEDENETDevice:
     def effect(self):
         """Return the current effect."""
         pattern_code = self.preset_pattern_num
+        if pattern_code == PRESET_MUSIC_MODE:
+            return MODE_MUSIC
         if pattern_code == EFFECT_CUSTOM_CODE:
             return EFFECT_CUSTOM
-        if not self.addressable:
-            return EFFECT_ID_NAME.get(pattern_code)
-        if pattern_code == 0x25:
-            return ADDRESSABLE_EFFECT_ID_NAME.get(self.raw_state.mode)
-        if pattern_code == 0x24:
-            return ASSESSABLE_MULTI_COLOR_ID_NAME.get(self.raw_state.mode)
-        return None
+        mode = self.raw_state.mode
+        if self.original_addressable:
+            effect_id = (pattern_code << 8) + mode - 99
+            return ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME.get(effect_id)
+        if self.addressable:
+            if pattern_code == 0x25:
+                return ADDRESSABLE_EFFECT_ID_NAME.get(mode)
+            if pattern_code == 0x24:
+                return ASSESSABLE_MULTI_COLOR_ID_NAME.get(mode)
+        return EFFECT_ID_NAME.get(pattern_code)
 
     @property
     def cool_white(self):
@@ -310,13 +331,13 @@ class LEDENETDevice:
             return MODE_COLOR
         elif pattern_code == EFFECT_CUSTOM_CODE:
             return MODE_CUSTOM
-        elif pattern_code == 0x62:
+        elif pattern_code == PRESET_MUSIC_MODE:
             return MODE_MUSIC
         elif PresetPattern.valid(pattern_code):
             return MODE_PRESET
         elif BuiltInTimer.valid(pattern_code):
             return BuiltInTimer.valtostr(pattern_code)
-        elif self.addressable:
+        elif self.addressable or self.original_addressable:
             return MODE_PRESET
         return None
 
@@ -426,17 +447,12 @@ class LEDENETDevice:
             return "No state data"
         mode = self.mode
         color_mode = self.color_mode
-        pattern = rx.preset_pattern
-        ww_level = rx.warm_white
-        power_state = rx.power_state
         power_str = "Unknown power state"
-        if power_state == self._protocol.on_byte:
+        if rx.power_state == self._protocol.on_byte:
             power_str = "ON "
-        elif power_state == self._protocol.off_byte:
+        elif rx.power_state == self._protocol.off_byte:
             power_str = "OFF "
 
-        delay = rx.speed
-        speed = utils.delayToSpeed(delay)
         if mode in STATIC_MODES:
             if color_mode in COLOR_MODES_RGB:
                 red = rx.red
@@ -445,31 +461,29 @@ class LEDENETDevice:
                 mode_str = f"Color: {(red, green, blue)}"
                 # Should add ability to get CCT from rgbwcapable*
                 if self.rgbwcapable:
-                    mode_str += f" White: {ww_level}"
+                    mode_str += f" White: {rx.warm_white}"
                 else:
                     mode_str += f" Brightness: {self.brightness}"
             elif color_mode == COLOR_MODE_DIM:
-                mode_str = f"Warm White: {utils.byteToPercent(ww_level)}%"
+                mode_str = f"Warm White: {utils.byteToPercent(rx.warm_white)}%"
             elif color_mode == COLOR_MODE_CCT:
                 cct_value = self.getWhiteTemperature()
                 mode_str = "CCT: {}K Brightness: {}%".format(
                     cct_value[0], cct_value[1] / 255
                 )
-            elif color_mode == COLOR_MODE_ADDRESSABLE:
-                mode_str = "Addressable"
         elif mode == MODE_PRESET:
-            pat = PresetPattern.valtostr(pattern)
-            mode_str = f"Pattern: {pat} (Speed {speed}%)"
+            pat = self.effect
+            mode_str = f"Pattern: {pat} (Speed {self.speed}%)"
         elif mode == MODE_CUSTOM:
-            mode_str = f"Custom pattern (Speed {speed}%)"
-        elif BuiltInTimer.valid(pattern):
-            mode_str = BuiltInTimer.valtostr(pattern)
+            mode_str = f"Custom pattern (Speed {self.speed}%)"
+        elif BuiltInTimer.valid(rx.preset_pattern):
+            mode_str = BuiltInTimer.valtostr(rx.preset_pattern)
         elif mode == MODE_MUSIC:
             mode_str = "Music"
         elif mode == MODE_SWITCH:
             mode_str = "Switch"
         else:
-            mode_str = f"Unknown mode 0x{pattern:x}"
+            mode_str = f"Unknown mode 0x{rx.preset_pattern:x}"
         mode_str += " raw state: "
         mode_str += utils.raw_state_to_dec(rx)
         return f"{power_str} [{mode_str}]"
@@ -562,10 +576,14 @@ class LEDENETDevice:
             return (255, 255)
         return (self.raw_state.warm_white, self.raw_state.cool_white)
 
+    @property
+    def speed(self):
+        if self.addressable or self.original_addressable:
+            return self.raw_state.speed
+        return utils.delayToSpeed(self.raw_state.speed)
+
     def getSpeed(self):
-        delay = self.raw_state.speed
-        speed = utils.delayToSpeed(delay)
-        return speed
+        return self.speed
 
     def _generate_levels_change(
         self,
@@ -658,7 +676,7 @@ class LEDENETDevice:
         the transition completes.
         """
         latency = STATE_CHANGE_LATENCY
-        if self.addressable:
+        if self.addressable or self.original_addressable:
             latency = ADDRESSABLE_STATE_CHANGE_LATENCY
         transition_time = latency + utils.speedToDelay(self.raw_state.speed) / 100
         self._transition_complete_time = time.monotonic() + transition_time
@@ -691,12 +709,16 @@ class LEDENETDevice:
             self._protocol = ProtocolLEDENET9Byte()
         elif protocol == PROTOCOL_LEDENET_ADDRESSABLE:
             self._protocol = ProtocolLEDENETAddressable()
+        elif protocol == PROTOCOL_LEDENET_ORIGINAL_ADDRESSABLE:
+            self._protocol = ProtocolLEDENETOriginalAddressable()
         else:
             raise ValueError(f"Invalid protocol: {protocol}")
 
     def _set_protocol_from_msg(self, full_msg, fallback_protocol):
         if self._is_addressable(full_msg[1]):
             self._protocol = ProtocolLEDENETAddressable()
+        elif self._is_original_addressable(full_msg[1]):
+            self._protocol = ProtocolLEDENETOriginalAddressable()
         # Devices that use an 9-byte protocol
         elif self._uses_9byte_protocol(full_msg[1]):
             self._protocol = ProtocolLEDENET9Byte()
@@ -705,9 +727,12 @@ class LEDENETDevice:
 
     def _generate_preset_pattern(self, pattern, speed):
         """Generate the preset pattern protocol bytes."""
-        if self.addressable:
-            if pattern not in ADDRESSABLE_EFFECT_ID_NAME:
+        if self.original_addressable:
+            if pattern not in ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME:
                 raise ValueError("Pattern must be between 1 and 300")
+        elif self.addressable:
+            if pattern not in ADDRESSABLE_EFFECT_ID_NAME:
+                raise ValueError("Pattern must be between 1 and 100")
         else:
             PresetPattern.valtostr(pattern)
             if not PresetPattern.valid(pattern):
@@ -732,4 +757,6 @@ class LEDENETDevice:
         """Convert an effect to a pattern code."""
         if self.addressable:
             return ADDRESSABLE_EFFECT_NAME_ID[effect]
+        if self.original_addressable:
+            return ORIGINAL_ADDRESSABLE_EFFECT_NAME_ID[effect]
         return PresetPattern.str_to_val(effect)
